@@ -17,24 +17,24 @@ public:
     QSqlDatabase &getSqlDatabase(int id = 0);
     TKvsDatabase &getKvsDatabase(TKvsDatabase::Type type);
 
-    void setTransactionEnabled(bool enable);
+    void setTransactionEnabled(bool enable, int id = 0);
     void release();
-    bool beginTransaction(QSqlDatabase &database);
     void commitTransactions();
     bool commitTransaction(int id = 0);
     void rollbackTransactions();
     bool rollbackTransaction(int id = 0);
     int idleTime() const;
+    static TDatabaseContext *currentDatabaseContext();
+    static void setCurrentDatabaseContext(TDatabaseContext *context);
 
 protected:
     void releaseKvsDatabases();
     void releaseSqlDatabases();
 
-    QMap<int, QSqlDatabase> sqlDatabases;
+    QMap<int, TSqlTransaction> sqlDatabases;
     QMap<int, TKvsDatabase> kvsDatabases;
 
 private:
-    TSqlTransaction transactions;
     uint idleElapsed {0};
 
     T_DISABLE_COPY(TDatabaseContext)
