@@ -21,14 +21,16 @@ public:
     virtual QString collectionName() const;
     virtual QString objectId() const { return QString(); }
     void setBsonData(const QVariantMap &bson);
-    bool create();
-    bool update();
-    bool remove();
+    bool create() override;
+    bool update() override;
+    bool upsert(const QVariantMap &criteria);
+    bool save() override;
+    bool remove() override;
     bool reload();
-    bool isNull() const { return objectId().isEmpty(); }
+    bool isNull() const override { return objectId().isEmpty(); }
     bool isNew() const { return objectId().isEmpty(); }
     bool isModified() const;
-    void clear();
+    void clear() override;
 
 protected:
     void syncToVariantMap();
